function ControlInput

% The global system equation is,
%           AA * Dss =  BB * ss  +  CC0 * uu  +  CC1 * Duu  +  CC2 * DDuu  +  DD
%
%  AA, BB -> stateVarNo x stateVarNo
%  CC0, CC1, CC2 -> stateVarNo x ctrlParmNo
%  DD, s -> stateVarNo x 1
%  u  -> ctrlParmNo x 1
%
% where ss is the state vector given by,
%           ss = [ u v w   DpAng DqAng DrAng   pAng qAng rAng   Dq_p(1) Dq_p(2) ... Dq_p(modesNo)   q_p(1) q_p(2) ... q_p(modesNo)]'
%
% and uu is the input vector of control parameters given by,
%           uu = [ cp(1)  cp(2)  ...  cp(ctrlParmNo) ]'
%
% Note: D = d/dt
%

global dt
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss                   % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global KK uu Duu DDuu last_Duu      % Gain Matrix & Inputs for Integral Control
global LastEqnNo            % Variable to keep track of the number of equation incorporated

% -+- Generating UU -+-
% Integral control
last_Duu = Duu;
Duu = KK*ss;
uu = uu + Duu*dt;
DDuu = (Duu - last_Duu)/dt;
