function ControlSystem

% The global system equation is,
%           AA * Dss =  BB * ss  +  CC0 * uu  +  CC1 * Duu  +  CC2 * DDuu  +  DD
%
%  AA, BB -> stateVarNo x stateVarNo
%  CC0, CC1, CC2 -> stateVarNo x ctrlParmNo
%  DD, s -> stateVarNo x 1
%  u  -> ctrlParmNo x 1
%
% where ss is the state vector given by,
%           ss = [ u v w   DpAng DqAng DrAng   pAng qAng rAng   Dq_p(1) Dq_p(2) ... Dq_p(modesNo)   q_p(1) q_p(2) ... q_p(modesNo)]'
%
% and uu is the input vector of control parameters given by,
%           uu = [ cp(1)  cp(2)  ...  cp(ctrlParmNo) ]'
%
% Note: D = d/dt
%

% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss                   % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global KK                   % Gain Matrix
global MM_full NN_full      % For the full integral system
global LastEqnNo            % Variable to keep track of the number of equation incorporated

global eigVals1

Rmat = inv(AA)*BB;
eigVals = eig(Rmat);
ord=.1;
thePoles = eig(inv(AA)*BB)*5 + (-(0.7+0.3*rand(stateVarNo, 1))*2 + (10*rand(stateVarNo, 1))*i)*ord;
sprintf('Placing poles of the system for Integral Control ..... \n  Determining K by Newton-Raphson iteration ....')
PolePlaceIgame;
%KK(2) = 9.600621147974315e+024;

tmpMat = inv(AA-CC2*KK);
MM11 = tmpMat*(BB+CC1*KK);
MM12 = tmpMat*CC0*KK;
MM21 = eye(stateVarNo);
MM22 = zeros(stateVarNo);
MM_full = [ MM11 MM12 ; MM21 MM22 ];    % / (0.5e100/stateVarNo);

NN1 = tmpMat*DD;
NN2 = zeros(stateVarNo, 1);
NN_full = [ NN1 ; NN2 ];
