function FMinertia
% Adds moments and forces due to engine inertia
% Presently only for pitch plane

global dl modesNo L0
global del_p d_del_p dd_del_p   % Thrust angle in pitch plane
global del_y d_del_y dd_del_p   % Thrust angle in yaw plane
global Tc Ts                    % Thrust values
global pAng qAng rAng
global u v w
global p q r
global du dv dw
global dp dq dr
global LC                     % Distance of the coordinate origin from hind end of the missile
global LR                     % Dist between engine cg and the hinge to which the engine is attached
global mR                     % Mass of engine
global I0 IR                  % moment of inertia of engine abt cg and hinge respectively
global U0 dU0
global F_a F_p M_p DC_p
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss                   % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global LastEqnNo            % Variable to keep track of the number of equation incorporated

% VV = [ independent_term
%        DDcp(1) DDcp(2) ... DDcp(ctrlParmNo)    Dcp(1) Dcp(2) ... Dcp(ctrlParmNo)   cp(1) cp(2) ... cp(ctrlParmNo)
%        Du Dv Dw    u v w    DDpAng DDqAng DDrAng    DpAng DqAng DrAng    pAng qAng rAng
%        DDq_p(1) DDq_p(2) ... DDq_p(modesNo)   Dq_p(1)  Dq_p(2) ...  Dq_p(modesNo)    q_p(1)  q_p(2) ...  q_p(modesNo) ]
%

F_a(1, 1+3*ctrlParmNo+1) = F_a(1, 1+3*ctrlParmNo+1) - mR/dl;

inertiaF = zeros(1+round(L0/dl), ExpressionVectorSize);
inertiaF(1, 2) = F_p(1, 2) - mR*LR;                                            % dd_del_p
inertiaF(1, 1+3*ctrlParmNo+7) = inertiaF(1, 1+3*ctrlParmNo+7) - mR*(LC+LR);    % dq
inertiaF(1, 1+3*ctrlParmNo+3) = inertiaF(1, 1+3*ctrlParmNo+3) - mR;            % dw
for m = 1:modesNo,
    inertiaF(1, 1+3*ctrlParmNo+15+m) = inertiaF(1, 1+3*ctrlParmNo+15+m) - mR*(phi_p(m, 0) - LR*Dphi_p(m, 0));
end
F_p = F_p + inertiaF/dl;

inertiaC = zeros(1+round(L0/dl), ExpressionVectorSize);
inertiaC(1, 1+3*ctrlParmNo+3) = inertiaC(1, 1+3*ctrlParmNo+3) - mR*LR;          % dw
inertiaC(1, 1+3*ctrlParmNo+7) = inertiaC(1, 1+3*ctrlParmNo+7) - (mR*LR*LC+IR);  % dq
inertiaC(1, 2) = inertiaC(1, 2) - IR/(dl*dl);                                           % dd_del_p
for m = 1:modesNo,
    inertiaC(1, 1+3*ctrlParmNo+15+m) = inertiaC(1, 1+3*ctrlParmNo+15+m) - (mR*LR*phi_p(m, 0) + IR*Dphi_p(m, 0));
end
DC_p = DC_p + inertiaC/(dl*dl);

M_p = M_p - inertiaC/dl + LC*inertiaF/dl;
