function OverallForceMomentEqn
% Update the linear and angular acleration terms using the
% net external Forces and Moments equation
global dl L0 m0 U0 dU0 dt mM qAng0 Q0 dQ0
global xcg ycg zcg
global Ixx Iyy Izz Ixy Iyz Izx
global pAng qAng rAng
global u v w
global p q r
global du dv dw
global dp dq dr
global F_a F_y F_p M_a M_y M_p 
global modesNo

% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss                   % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global LastEqnNo            % Variable to keep track of the number of equation incorporated

% VV = [ independent_term
%        DDcp(1) DDcp(2) ... DDcp(ctrlParmNo)    Dcp(1) Dcp(2) ... Dcp(ctrlParmNo)   cp(1) cp(2) ... cp(ctrlParmNo)
%        Du Dv Dw    u v w    DDpAng DDqAng DDrAng    DpAng DqAng DrAng    pAng qAng rAng
%        DDq_p(1) DDq_p(2) ... DDq_p(modesNo)   Dq_p(1)  Dq_p(2) ...  Dq_p(modesNo)    q_p(1)  q_p(2) ...  q_p(modesNo) ]
%

% Calculating overall force and moments from pitch and yaw plane forces and moments.
for m = 1:ExpressionVectorSize,
    Fx(m) = 0; 
    Fy(m) = 0;
    Fz(m) = 0;
    Mx(m) = 0;
    My(m) = 0;
    Mz(m) = 0;
end
for x = 0:dl:L0,
    indx = 1+round(x/dl);
    for m = 1:ExpressionVectorSize,
        Fx(m) = Fx(m) + F_a(indx, m)*dl;
        Fy(m) = Fy(m) + F_y(indx, m)*dl;
        Fz(m) = Fz(m) + F_p(indx, m)*dl;
        My(m) = My(m) + M_p(indx, m)*dl; % - F_p(1+x/dl)*(x-LC)*dl;
        Mz(m) = Mz(m) + M_y(indx, m)*dl; % + F_y(1+x/dl)*(x-LC)*dl;
        Mx(m) = Mx(m) + M_a(indx, m)*dl;
    end
end

% Equations 45 to 50

thisTmpEqn = -Fx;
thisTmpEqn(1+3*ctrlParmNo+1) = thisTmpEqn(1+3*ctrlParmNo+1) + mM;
thisTmpEqn(1+3*ctrlParmNo+9) = thisTmpEqn(1+3*ctrlParmNo+9) - mM*ycg;
thisTmpEqn(1+3*ctrlParmNo+8) = thisTmpEqn(1+3*ctrlParmNo+8) + mM*zcg;
generateEquation(thisTmpEqn);

thisTmpEqn = -Fy;
thisTmpEqn(1+3*ctrlParmNo+2) = thisTmpEqn(1+3*ctrlParmNo+2) + mM;
thisTmpEqn(1+3*ctrlParmNo+12) = thisTmpEqn(1+3*ctrlParmNo+12) + mM*U0;
thisTmpEqn(1+3*ctrlParmNo+9) = thisTmpEqn(1+3*ctrlParmNo+9) + mM*xcg;
thisTmpEqn(1+3*ctrlParmNo+7) = thisTmpEqn(1+3*ctrlParmNo+7) - mM*zcg;
generateEquation(thisTmpEqn);

thisTmpEqn = -Fz;
thisTmpEqn(1+3*ctrlParmNo+3) = thisTmpEqn(1+3*ctrlParmNo+3) + mM;
thisTmpEqn(1+3*ctrlParmNo+11) = thisTmpEqn(1+3*ctrlParmNo+11) - mM*U0;
thisTmpEqn(1+3*ctrlParmNo+8) = thisTmpEqn(1+3*ctrlParmNo+8) - mM*xcg;
thisTmpEqn(1+3*ctrlParmNo+7) = thisTmpEqn(1+3*ctrlParmNo+7) + mM*ycg;
generateEquation(thisTmpEqn);

thisTmpEqn = -Mx;
thisTmpEqn(1+3*ctrlParmNo+7) = thisTmpEqn(1+3*ctrlParmNo+7) + Ixx;
thisTmpEqn(1+3*ctrlParmNo+8) = thisTmpEqn(1+3*ctrlParmNo+8) - Ixy;
thisTmpEqn(1+3*ctrlParmNo+9) = thisTmpEqn(1+3*ctrlParmNo+9) - Izx;
thisTmpEqn(1+3*ctrlParmNo+11) = thisTmpEqn(1+3*ctrlParmNo+11) - U0*mM*ycg;
thisTmpEqn(1+3*ctrlParmNo+12) = thisTmpEqn(1+3*ctrlParmNo+12) - U0*mM*zcg;
thisTmpEqn(1+3*ctrlParmNo+2) = thisTmpEqn(1+3*ctrlParmNo+2) - mM*zcg;
thisTmpEqn(1+3*ctrlParmNo+3) = thisTmpEqn(1+3*ctrlParmNo+3) + mM*ycg;
generateEquation(thisTmpEqn);

thisTmpEqn = -My;
thisTmpEqn(1+3*ctrlParmNo+7) = thisTmpEqn(1+3*ctrlParmNo+7) - Ixy;
thisTmpEqn(1+3*ctrlParmNo+8) = thisTmpEqn(1+3*ctrlParmNo+8) + Iyy;
thisTmpEqn(1+3*ctrlParmNo+9) = thisTmpEqn(1+3*ctrlParmNo+9) - Iyz;
thisTmpEqn(1+3*ctrlParmNo+11) = thisTmpEqn(1+3*ctrlParmNo+11) + U0*mM*xcg;
thisTmpEqn(1+3*ctrlParmNo+1) = thisTmpEqn(1+3*ctrlParmNo+1) + mM*zcg;
thisTmpEqn(1+3*ctrlParmNo+3) = thisTmpEqn(1+3*ctrlParmNo+3) + mM*xcg;
generateEquation(thisTmpEqn);

thisTmpEqn = -My;
thisTmpEqn(1+3*ctrlParmNo+7) = thisTmpEqn(1+3*ctrlParmNo+7) - Izx;
thisTmpEqn(1+3*ctrlParmNo+8) = thisTmpEqn(1+3*ctrlParmNo+8) - Iyz;
thisTmpEqn(1+3*ctrlParmNo+9) = thisTmpEqn(1+3*ctrlParmNo+9) + Izz;
thisTmpEqn(1+3*ctrlParmNo+12) = thisTmpEqn(1+3*ctrlParmNo+12) + U0*mM*xcg;
thisTmpEqn(1+3*ctrlParmNo+1) = thisTmpEqn(1+3*ctrlParmNo+1) - mM*ycg;
thisTmpEqn(1+3*ctrlParmNo+2) = thisTmpEqn(1+3*ctrlParmNo+2) + mM*xcg;
generateEquation(thisTmpEqn);
