function RootLocusPlot

% 
global time Tdata1 Tdata2
global solveTimeSteps
global dt L0 dl modesNo
global F_a F_y F_p M_a M_y M_p
% Global coeficients
global F_p_ddq_coef F_p_dq_coef F_p_q_coef
% Angle, Velocity and accleration components --> constants
global U0 V0 W0 dU0
global P0 Q0 R0
% Purturbation Angle, Velocity and accleration components --> Time dependant scalers
global pAng qAng rAng pAng0 qAng0 rAng0
global u v w
global p q r
global du dv dw
global dp dq dr
global del_p d_del_p dd_del_p   % Thrust angle in pitch plane
global del_y d_del_y dd_del_p   % Thrust angle in yaw plane
global Tc Ts                    % Thrust values
global q_p dq_p ddq_p q_y dq_y ddq_y        % Initial shape
global zeta_p omgMode_p
global DC_p DC_p_ddq_coef DC_p_dq_coef DC_p_q_coef  % Derivative of moments due to couple along length
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss rr                % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global KK uu Duu DDuu last_Duu      % Gain Matrix & Inputs for Integral Control
global LastEqnNo            % Variable to keep track of the number of equation incorporated

global isTimeInvariant

warning off


% Initilizing Values
globals
dU0 = 0;
V0 = 0;
W0 = 0;
P0 = 0;
Q0 = 0;
R0 = 0;
pAng0 = 0;
qAng0 = 0.1;
rAng0 = 0;

Ts = 1e7;
U0 = 1000;
for Tc = 1e6:1e6:2e8,
        initiateSysEqn
        
        % -----------------------------------------------------------------
    
        Tc,
        % Force Calculation
        F_a = zeros(1+round(L0/dl), ExpressionVectorSize);
        F_p = zeros(1+round(L0/dl), ExpressionVectorSize);
        F_y = zeros(1+round(L0/dl), ExpressionVectorSize);
        M_a = zeros(1+round(L0/dl), ExpressionVectorSize);
        M_p = zeros(1+round(L0/dl), ExpressionVectorSize);
        M_y = zeros(1+round(L0/dl), ExpressionVectorSize);
        DC_p = zeros(1+round(L0/dl), ExpressionVectorSize);

        FMthrust;            % Due to Thrust
        FMinertia;           % Due to engine inertia
        FMaerodynamic;       % Aerodynamic force
        % FMgravity
        % etc etc
        
        % -----------------------------------------------------------------

        
        % Add structural equations due to flexibility
        structuralEqn_p;     % On pitch plane
        
        % Equations for from net Force and Moment balance
        OverallForceMomentEqn;
    
        % -----------------------------------------------------------------
        eigArray(U0/100, :) = (eig(inv(AA)*BB))';
        
end

figure;
plot(eigArray, 'b');
title('Locus of poles of Open loop system with variation of Tc from 10^6 to 2*10^8');
