function Solve_System
% 
global time Tdata1 Tdata2
global solveTimeSteps
global dt L0 dl modesNo
global F_a F_y F_p M_a M_y M_p
% Global coeficients
global F_p_ddq_coef F_p_dq_coef F_p_q_coef
% Angle, Velocity and accleration components --> constants
global U0 V0 W0 dU0
global P0 Q0 R0
% Purturbation Angle, Velocity and accleration components --> Time dependant scalers
global pAng qAng rAng pAng0 qAng0 rAng0
global u v w
global p q r
global du dv dw
global dp dq dr
global del_p d_del_p dd_del_p   % Thrust angle in pitch plane
global del_y d_del_y dd_del_p   % Thrust angle in yaw plane
global Tc Ts                    % Thrust values
global q_p dq_p ddq_p q_y dq_y ddq_y        % Initial shape
global zeta_p omgMode_p
global DC_p DC_p_ddq_coef DC_p_dq_coef DC_p_q_coef  % Derivative of moments due to couple along length
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss rr                % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global KK uu Duu DDuu last_Duu      % Gain Matrix & Inputs for Integral Control
global LastEqnNo            % Variable to keep track of the number of equation incorporated

global isTimeInvariant

warning off

isTimeInvariant = 1;
doFull = 1;

solveTimeSteps = 1000;
solveTime = solveTimeSteps*dt;      % Time for which solution to be performed

% Initilizing Values
globals
U0 = 1000;
dU0 = 0;
V0 = 0;
W0 = 0;
P0 = 0;
Q0 = 0;
R0 = 0;
pAng0 = 0;
qAng0 = 0.1;
rAng0 = 0;

% The global system equation is,
%           AA * Dss =  BB * ss  +  CC0 * uu  +  CC1 * Duu  +  CC2 * DDuu  +  DD
%
%  AA, BB -> stateVarNo x stateVarNo
%  CC0, CC1, CC2 -> stateVarNo x ctrlParmNo
%  DD, s -> stateVarNo x 1
%  u  -> ctrlParmNo x 1
%
% where ss is the state vector given by,
%           ss = [ u v w   DpAng DqAng DrAng   pAng qAng rAng   Dq_p(1) Dq_p(2) ... Dq_p(modesNo)   q_p(1) q_p(2) ... q_p(modesNo)]'
%
% and uu is the input vector of control parameters given by,
%           uu = [ cp(1)  cp(2)  ...  cp(ctrlParmNo) ]'
%
% Note: D = d/dt
%

ss = zeros(stateVarNo, 1);
rr = zeros(stateVarNo, 1);
ss(9+modesNo+1) = 1e-3;

uu = zeros(ctrlParmNo, 1);
Duu = zeros(ctrlParmNo, 1);
DDuu = zeros(ctrlParmNo, 1);
last_Duu = zeros(ctrlParmNo, 1);

Ts = 1e7;
Tc = 1e7;

% Initiating loop


% Looping
for time = 0:dt:solveTime,

    
    if isTimeInvariant==0 || time==0
        
        initiateSysEqn
        
        % -----------------------------------------------------------------
    
        
        % Force Calculation
        sprintf('Determining Forces .....')
        
        %force_calculate
        F_a = zeros(1+round(L0/dl), ExpressionVectorSize);
        F_p = zeros(1+round(L0/dl), ExpressionVectorSize);
        F_y = zeros(1+round(L0/dl), ExpressionVectorSize);
        M_a = zeros(1+round(L0/dl), ExpressionVectorSize);
        M_p = zeros(1+round(L0/dl), ExpressionVectorSize);
        M_y = zeros(1+round(L0/dl), ExpressionVectorSize);
        DC_p = zeros(1+round(L0/dl), ExpressionVectorSize);

        FMthrust;            % Due to Thrust
        FMinertia;           % Due to engine inertia
        FMaerodynamic;       % Aerodynamic force
        %FMgravity;
        % etc etc
        
        % -----------------------------------------------------------------

        
        % Adding equations to system Matrix
        sprintf('Adding equations due to structural flexibility .....')
        
        % Add structural equations due to flexibility
        structuralEqn_p;     % On pitch plane
        
        % Equations for from net Force and Moment balance
        OverallForceMomentEqn;
    
        % -----------------------------------------------------------------
        
        
        % Control loop for determining Gain KK
        sprintf('Determining gain matrix K .....')
        ControlSystem;
        % ....
        
        % -----------------------------------------------------------------
        
        
        % Checking the Open & Closed loop system for Stability, controllability, etc
        % Printing out the summery
        sprintf('Checking the system ..... \n     Plotting System Poles \n     Printing system summery .....')
        SysCheck;
        
        %  -----------------------------------------------------------------
        
    end
    
    % Original time loop
    if mod(round(time/dt), 1) == 0
        sprintf('time = %d :   Determining input u ; Updating state vector s ; Saving Time Series Data .....', time)
    end
    % Control loop for updating input
    if doFull ~= 1
        ControlInput;
    end
    % Updates the state vector
    StateEval;

    % -----------------------------------------------------------------
    
    % Outputs:
    
    % Time Series data storing
    TimeSeriesProbes(time);
    
end

TimeSeriesPlots;
