function StateEval
% Evaluates the state vector

% The global system equation is,
%           AA * Dss =  BB * ss  +  CC0 * uu  +  CC1 * Duu  +  CC2 * DDuu  +  DD
%
%  AA, BB -> stateVarNo x stateVarNo
%  CC0, CC1, CC2 -> stateVarNo x ctrlParmNo
%  DD, s -> stateVarNo x 1
%  u  -> ctrlParmNo x 1
%
% where ss is the state vector given by,
%           ss = [ u v w   DpAng DqAng DrAng   pAng qAng rAng   Dq_p(1) Dq_p(2) ... Dq_p(modesNo)   q_p(1) q_p(2) ... q_p(modesNo)]'
%
% and uu is the input vector of control parameters given by,
%           uu = [ cp(1)  cp(2)  ...  cp(ctrlParmNo) ]'
%
% Note: D = d/dt
%

global dt doFull
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss rr                % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global KK
global MM_full NN_full      % For the full integral system
global LastEqnNo            % Variable to keep track of the number of equation incorporated
global del_p d_del_p dd_del_p   % Thrust angle in pitch plane
global uu last_uu last2last_uu Duu DDuu KK  % Control loop parameters & inputs


% Updating state vector
if doFull ~= 1
    AAinv = inv(AA);
    ss = ss  +  dt * AAinv*(BB*ss + CC0*uu + CC1*Duu + CC2*DDuu + DD);
else
    ss_rr = [ ss ; rr ];
    sub_steps = 1000;
    sub_dt = dt/sub_steps;
    for a=1:sub_steps,
        ss_rr = ss_rr  +  sub_dt * (MM_full*ss_rr + NN_full);
    end
    ss = ss_rr(1:stateVarNo);
    rr = ss_rr(1+stateVarNo:2*stateVarNo);
end
