function SysCheck
%
% The global system equation is,
%           AA * Dss =  BB * ss  +  CC0 * uu  +  CC1 * Duu  +  CC2 * DDuu  +  DD
%
%  AA, BB -> stateVarNo x stateVarNo
%  CC0, CC1, CC2 -> stateVarNo x ctrlParmNo
%  DD, s -> stateVarNo x 1
%  u  -> ctrlParmNo x 1
%
% where ss is the state vector given by,
%           ss = [ u v w   DpAng DqAng DrAng   pAng qAng rAng   Dq_p(1) Dq_p(2) ... Dq_p(modesNo)   q_p(1) q_p(2) ... q_p(modesNo)]'
%
% and uu is the input vector of control parameters given by,
%           uu = [ cp(1)  cp(2)  ...  cp(ctrlParmNo) ]'
%
% Note: D = d/dt
%

global modesNo
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss                   % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global MM_full NN_full      % For the full integral system
global LastEqnNo            % Variable to keep track of the number of equation incorporated
global uu last_uu last2last_uu Duu DDuu KK  % Control loop parameters & inputs


sprintf('System properties: \n     System equation: A*d(ss) = B*ss + C0*uu + C1*d(uu) + C2*dd(uu) + D \n     Integral Control: d(uu) = K*ss \n     [Note: d = d/dt]')


sprintf('Poles of Open Loop system \n i.e. Eigenvalues of inv(A)*B .....')
Rmat = inv(AA)*BB;
eigenVals = eig(Rmat);
eigenVals,
hold on;
figure;
plot(eigenVals, '.');
title('Poles of Open Loop system');
hold off;

sprintf('Poles of Closed Loop system with Integral Control ..... \n i.e. Eigenvalues of \n         --                                                             --\n        ||                                |                              ||\n        || inv(A-C2*K)*(B+C1*K) - lamb*I  |     inv(A-C2*K)*C0*K         ||\n        ||                                |                              ||\n        ||--------------------------------|------------------------------||      \n        ||                                |                              ||\n        ||             I                  |           -lamb*I            ||\n        ||                                |                              ||\n         --                                                             -- .....')
sprintf('With zero gain .....')
zero_KK = zeros(ctrlParmNo, stateVarNo);
this_KK = zero_KK;
tmpMat = inv(AA-CC2*this_KK);
MM11 = tmpMat*(BB+CC1*this_KK);
MM12 = tmpMat*CC0*this_KK;
MM21 = eye(stateVarNo);
MM22 = zeros(stateVarNo);
MM = [ MM11 MM12 ; MM21 MM22 ];
eigenVals = eig(MM);
eigenVals,
hold on;
figure;
plot(eigenVals, '.');
title('Poles of Closed Loop system with zero gain');
hold off;

if KK == zero_KK
    sprintf('Gain determined to stabilize Integral feedback loop is ZERO!!!!!')
else
    sprintf('With gain determined to stabilize Integral feedback loop =')
    KK,
    eigenVals = eig(MM_full);
    eigenVals,
    hold on;
    figure;
    plot(eigenVals, '.');
    title('Poles of Closed Loop system with gain determined to stabilize Integral feedback loop');
    hold off;
end


% Saving the system Matrices
save 'last_run_system.mat' AA BB CC0 CC1 CC2 DD KK

pause;
