function initiateSysEqn
% initiates the System Equations -- defines extra system variables
%
% The global system equation is,
%           AA * Dss =  BB * ss  +  CC0 * uu  +  CC1 * Duu  +  CC2 * DDuu  +  DD
%
%  AA, BB -> stateVarNo x stateVarNo
%  CC0, CC1, CC2 -> stateVarNo x ctrlParmNo
%  DD, s -> stateVarNo x 1
%  u  -> ctrlParmNo x 1
%
% where ss is the state vector given by,
%           ss = [ u v w   DpAng DqAng DrAng   pAng qAng rAng   Dq_p(1) Dq_p(2) ... Dq_p(modesNo)   q_p(1) q_p(2) ... q_p(modesNo)]'
%
% and uu is the input vector of control parameters given by,
%           uu = [ cp(1)  cp(2)  ...  cp(ctrlParmNo) ]'
%
% Note: D = d/dt
%
%
% This function adds the equations
%           DpAng = dpAng/dt
%           DqAng = dqAng/dt
%           DrAng = drAng/dt
%           Dq_p(i) = dq_p(i)/dt    , i = 1 to modesNo
%

global modesNo
% State space formulation
global stateVarNo           % No of state variables
global ctrlParmNo           % No of control parameters
global ExpressionVectorSize % No of elements in an 'expression vector'
global ss rr                % State vector
global AA BB CC0 CC1 CC2 DD % System equation matrices
global KK                   % Gain Matrix
global MM_full NN_full      % For the full integral system
global LastEqnNo            % Variable to keep track of the number of equation incorporated

AA = zeros(stateVarNo, stateVarNo);
BB = zeros(stateVarNo, stateVarNo);
CC0 = zeros(stateVarNo, ctrlParmNo);
CC1 = zeros(stateVarNo, ctrlParmNo);
CC2 = zeros(stateVarNo, ctrlParmNo);
DD = zeros(stateVarNo, 1);
KK = zeros(ctrlParmNo, stateVarNo);

LastEqnNo = 0;

% DpAng = dpAng/dt
% DqAng = dqAng/dt
% DrAng = drAng/dt
for a = 1:3,
    LastEqnNo = LastEqnNo + 1;
    AA(LastEqnNo, 6+a) = 1;
    BB(LastEqnNo, 3+a) = 1;
    CC0(LastEqnNo) = 0;
    CC1(LastEqnNo) = 0;
    CC2(LastEqnNo) = 0;
    DD(LastEqnNo) = 0;
end

% Dq_p(i) = dq_p(i)/dt    , i = 1 to modesNo
for a = 1:modesNo,
    LastEqnNo = LastEqnNo + 1;
    AA(LastEqnNo, 9+modesNo+a) = 1;
    BB(LastEqnNo, 9+a) = 1;
    CC0(LastEqnNo) = 0;
    CC1(LastEqnNo) = 0;
    CC2(LastEqnNo) = 0;
    DD(LastEqnNo) = 0;
end
